Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/bme680_simpletest.py
    :caption: examples/bme680_simpletest.py
    :linenos:

SPI Example
-----------

Showcase the use of the SPI bus to read the sensor data.

.. literalinclude:: ../examples/bme680_spi.py
    :caption: examples/bme680_spi.py
    :linenos:
